//Name:		AutoDeleter.h
//Author:	Brian Tietz
//Copyright 1999
//Conventions:
//	Global constants (declared with const) and #defines - begin with "c_" followed by lowercase
//		words separated by underscores.
//		(E.G., #define c_my_constant 5).
//		(E.G., const int c_my_constant = 5;).
//	Global variables - begin with "g_" followed by lowercase words separated by underscores.
//		(E.G., int g_my_global;).
//	New data types (classes, structs, typedefs, etc.) - begin with an uppercase letter followed by
//		lowercase words separated by uppercase letters.  Enumerated constants contain a prefix
//		associating them with a particular enumerated set.
//		(E.G., typedef int MyTypedef;).
//		(E.G., enum MyEnumConst {c_mec_one, c_mec_two};)
//	Private member variables - begin with "m_" followed by lowercase words separated by underscores.
//		(E.G., int m_my_member;).
//	Public or friend-accessible member variables - all lowercase words separated by underscores.
//		(E.G., int public_member;).
//	Argument and local variables - begin with a lowercase letter followed by
//		lowercase words separated by underscores.  If the name is already taken by a public member
//		variable, prefix with a_ or l_
//		(E.G., int my_local; int a_my_arg, int l_my_local).
//	Functions (member or global) - begin with an uppercase letter followed by lowercase words
//		separated by uppercase letters.
//		(E.G., void MyFunction(void);).

//Usage:
//If you get an object by new, but your function returns in various different places, it's annoying to have
//to delete the object pointer at every place it's used.  Instead, create a static AutoDeleter on the stack,
//like this:
//	char* must_delete = new char[10];
//	AutoDeleterArray<char*> deleter(must_delete);
//  SomeObject* must_delete_too = new SomeObject();
//	AutoDeleter<SomeObject*> deleter(must_delete_too);


#ifndef _AUTODELETER_H_
#define _AUTODELETER_H_


template<class list_content_type> class AutoDeleter
{
	private:
		list_content_type m_content;

	public:
		AutoDeleter(list_content_type content)
		{
			m_content = content;
		}

		~AutoDeleter()
		{
			if(m_content)
				delete m_content;
		}

		void DoNotDelete()
		{
			m_content = NULL;
		}
};


template<class list_content_type> class AutoDeleterArray
{
	private:
		list_content_type m_content;

	public:
		AutoDeleterArray(list_content_type content)
		{
			m_content = content;
		}

		~AutoDeleterArray()
		{
			if(m_content)
				delete[] m_content;
		}

		void DoNotDelete()
		{
			m_content = NULL;
		}
};


#endif //_AUTODELETER_H_
