//Name:		FSBox.cpp
//Author:	Brian Tietz
//Copyright 1999
//Conventions:
//	Global constants (declared with const) and #defines - begin with "c_" followed by lowercase
//		words separated by underscores.
//		(E.G., #define c_my_constant 5).
//		(E.G., const int c_my_constant = 5;).
//	Global variables - begin with "g_" followed by lowercase words separated by underscores.
//		(E.G., int g_my_global;).
//	New data types (classes, structs, typedefs, etc.) - begin with an uppercase letter followed by
//		lowercase words separated by uppercase letters.  Enumerated constants contain a prefix
//		associating them with a particular enumerated set.
//		(E.G., typedef int MyTypedef;).
//		(E.G., enum MyEnumConst {c_mec_one, c_mec_two};)
//	Private member variables - begin with "m_" followed by lowercase words separated by underscores.
//		(E.G., int m_my_member;).
//	Public or friend-accessible member variables - all lowercase words separated by underscores.
//		(E.G., int public_member;).
//	Argument and local variables - begin with a lowercase letter followed by
//		lowercase words separated by underscores.  If the name is already taken by a public member
//		variable, prefix with a_ or l_
//		(E.G., int my_local; int a_my_arg, int l_my_local).
//	Functions (member or global) - begin with an uppercase letter followed by lowercase words
//		separated by uppercase letters.
//		(E.G., void MyFunction(void);).


//******************************************************************************************************
//**** System header files
//******************************************************************************************************
#include <ClassInfo.h>


//******************************************************************************************************
//**** Project header files
//******************************************************************************************************
#include "FSBox.h"


//******************************************************************************************************
//**** FSBox
//******************************************************************************************************
FSBox::FSBox(const char *name, uint32 resize_flags, uint32 flags, border_style border)
: BBox(BRect(0,0,100,30),name,resize_flags,flags,border)
{ }


void FSBox::SetVisualWidth(float width)
{
	ResizeTo(width,Frame().Height());
}


void FSBox::SetVisualHeight(float height)
{
	BRect frame = Frame();
	BRect visual_frame = VisualFrame();
	ResizeTo(frame.Width(),height-(frame.Height()-visual_frame.Height()));
}


void FSBox::SetVisualSize(float width, float height)
{
	BRect frame = Frame();
	BRect visual_frame = VisualFrame();
	ResizeTo(width,height-(frame.Height()-visual_frame.Height()));
}


float FSBox::VisualLeft()
{
	return Frame().left;
}


float FSBox::VisualRight()
{
	return Frame().right;
}


float FSBox::VisualTop()
{
	const char* label = Label();
	if(label)
	{
		BFont font;
		GetFont(&font);
		struct font_height font_height_struct;
		font.GetHeight(&font_height_struct);
		float view_font_ascent = ceil(font_height_struct.ascent);
		const char* string[1] = {label};
		struct escapement_delta deltas[1] = {{0,0}};
		BRect bounding_box[1];
		font.GetBoundingBoxesForStrings(string,1,B_SCREEN_METRIC,deltas,bounding_box);
		float title_true_ascent = 0-bounding_box[0].top;
		return Frame().top + ceil(view_font_ascent-title_true_ascent) - 2;
	}
	else
	{
		BView* label_view = LabelView();
		if(label_view)
		{
			FSView* fs_label_view = cast_as(label_view,FSView);
			if(fs_label_view)
				return Frame().top + (fs_label_view->VisualTop() - Bounds().top);
			else
				return Frame().top + (label_view->Frame().top - Bounds().top);
		}
		else
			return Frame().top;
	}
	return 0;	//Never get here, but makes the compiler happy
}


float FSBox::VisualBottom()
{
	return Frame().bottom;
}


void FSBox::MoveToVisualPosition(BPoint visual_position)
{
	MoveTo(visual_position.x,visual_position.y-(VisualTop()-Frame().top));
}


void FSBox::SetInteriorRectSize(float width, float height)
{
	ResizeTo(LeftMargin()+width+RightMargin(),TopMargin()+height+BottomMargin());
}


BRect FSBox::InteriorRect()
{
	float border_thickness = LeftRightBottomMargin();
		
	BRect rect = Bounds();
	rect.InsetBy(border_thickness,border_thickness);
	rect.top = LabelVisualBottom()+1;
	return rect;
}


float FSBox::LabelVisualBottom()
{
	const char* label = Label();
	if(label)
	{
		BFont font;
		GetFont(&font);
		struct font_height font_height_struct;
		font.GetHeight(&font_height_struct);
		float view_font_height = ceil(font_height_struct.ascent) + ceil(font_height_struct.descent);
		return Bounds().top + view_font_height - 5;
	}
	else
	{
		BView* label_view = LabelView();
		if(label_view)
		{
			FSView* fs_label_view = cast_as(label_view,FSView);
			if(fs_label_view)
				return fs_label_view->VisualBottom();
			else
				return label_view->Frame().bottom;
		}
	}
	return LeftRightBottomMargin();
}


float FSBox::BorderTop()
{
	const char* label = Label();
	if(label)
	{
		BFont font;
		GetFont(&font);
		struct font_height font_height_struct;
		font.GetHeight(&font_height_struct);
		float view_font_height = ceil(font_height_struct.ascent) + ceil(font_height_struct.descent);
		return Frame().top + floor(view_font_height/2);
	}
	else
	{
		BView* label_view = LabelView();
		if(label_view)
			return Frame().top + floor(label_view->Frame().Height()/2);
	}
	return 0;
}


float FSBox::MinimumWidth()
{
	const char* label = Label();
	if(label)
	{
		BFont font;
		GetFont(&font);
		return ceil(font.StringWidth(Label())) + 6 + 2*LeftRightBottomMargin();
	}
	else
	{
		BView* label_view = LabelView();
		if(label_view)
			return label_view->Frame().Width() + 6 + 2*LeftRightBottomMargin();
	}
	return 6 + 6 + 2*LeftRightBottomMargin();
}


float FSBox::TopMargin()
{
	return (Frame().Height() - InteriorRect().Height()) - BottomMargin();
}


float FSBox::LeftRightBottomMargin()
{
	border_style style = Border();
	float border_thickness = 2;
	if(style == B_PLAIN_BORDER)
		border_thickness = 1;
	else if(style == B_NO_BORDER)
		border_thickness = 0;
	return border_thickness;
}
