//Name:		FSBox.h
//Author:	Brian Tietz
//Copyright 1999
//Conventions:
//	Global constants (declared with const) and #defines - begin with "c_" followed by lowercase
//		words separated by underscores.
//		(E.G., #define c_my_constant 5).
//		(E.G., const int c_my_constant = 5;).
//	Global variables - begin with "g_" followed by lowercase words separated by underscores.
//		(E.G., int g_my_global;).
//	New data types (classes, structs, typedefs, etc.) - begin with an uppercase letter followed by
//		lowercase words separated by uppercase letters.  Enumerated constants contain a prefix
//		associating them with a particular enumerated set.
//		(E.G., typedef int MyTypedef;).
//		(E.G., enum MyEnumConst {c_mec_one, c_mec_two};)
//	Private member variables - begin with "m_" followed by lowercase words separated by underscores.
//		(E.G., int m_my_member;).
//	Public or friend-accessible member variables - all lowercase words separated by underscores.
//		(E.G., int public_member;).
//	Argument and local variables - begin with a lowercase letter followed by
//		lowercase words separated by underscores.  If the name is already taken by a public member
//		variable, prefix with a_ or l_
//		(E.G., int my_local; int a_my_arg, int l_my_local).
//	Functions (member or global) - begin with an uppercase letter followed by lowercase words
//		separated by uppercase letters.
//		(E.G., void MyFunction(void);).


#ifndef _FONT_SENSITIVE_BOX_H_
#define _FONT_SENSITIVE_BOX_H_


//******************************************************************************************************
//**** System header files
//******************************************************************************************************
#include <Box.h>


//******************************************************************************************************
//**** Project header files
//******************************************************************************************************
#include "FSView.h"


//******************************************************************************************************
//**** FSBox
//******************************************************************************************************
class FSBox	: public BBox, public FSView
{
	public:
		FSBox(const char *name = NULL, uint32 resize_flags = B_FOLLOW_LEFT|B_FOLLOW_TOP,
			uint32 flags = B_WILL_DRAW|B_FRAME_EVENTS|B_NAVIGABLE_JUMP,
			border_style border = B_FANCY_BORDER);

		//FSView implementation
		virtual float VisualLeft();
		virtual float VisualRight();
		virtual float VisualTop();
		virtual float VisualBottom();
		virtual void SetVisualWidth(float width);
		virtual void SetVisualHeight(float height);
		virtual void SetVisualSize(float width, float height);
		virtual void MoveToVisualPosition(BPoint visual_position);

		void SetInteriorRectSize(float width, float height);
		BRect InteriorRect();			//In the Box's coordinate space, not the parent
		float LabelVisualBottom();		//In the Box's coordinate space, not the parent
		float BorderTop();				//In the parent's coordinate space
		float MinimumWidth();			//Minimum width needed to properly accommodate the label
		float TopMargin();				//Top margin, relative to frame rect
		inline float LeftMargin() {return LeftRightBottomMargin();}
		inline float RightMargin() {return LeftRightBottomMargin();}
		inline float BottomMargin() {return LeftRightBottomMargin();}
		float LeftRightBottomMargin();
};


#endif //_FONT_SENSITIVE_BOX_H_
