//Name:		FSButton.cpp
//Author:	Brian Tietz
//Copyright 1999
//Conventions:
//	Global constants (declared with const) and #defines - begin with "c_" followed by lowercase
//		words separated by underscores.
//		(E.G., #define c_my_constant 5).
//		(E.G., const int c_my_constant = 5;).
//	Global variables - begin with "g_" followed by lowercase words separated by underscores.
//		(E.G., int g_my_global;).
//	New data types (classes, structs, typedefs, etc.) - begin with an uppercase letter followed by
//		lowercase words separated by uppercase letters.  Enumerated constants contain a prefix
//		associating them with a particular enumerated set.
//		(E.G., typedef int MyTypedef;).
//		(E.G., enum MyEnumConst {c_mec_one, c_mec_two};)
//	Private member variables - begin with "m_" followed by lowercase words separated by underscores.
//		(E.G., int m_my_member;).
//	Public or friend-accessible member variables - all lowercase words separated by underscores.
//		(E.G., int public_member;).
//	Argument and local variables - begin with a lowercase letter followed by
//		lowercase words separated by underscores.  If the name is already taken by a public member
//		variable, prefix with a_ or l_
//		(E.G., int my_local; int a_my_arg, int l_my_local).
//	Functions (member or global) - begin with an uppercase letter followed by lowercase words
//		separated by uppercase letters.
//		(E.G., void MyFunction(void);).


//******************************************************************************************************
//**** Project header files
//******************************************************************************************************
#include "FSButton.h"


//******************************************************************************************************
//**** FSButton
//******************************************************************************************************
FSButton::FSButton(const char* name, const char* label, BMessage* message, button_width width_mode,
	uint32 resize_mask, uint32 flags)
: BButton(BRect(0,0,10,20),name,label,message,resize_mask,flags)
{
	m_width_mode = width_mode;
	AdjustSizeForFont();
}

void FSButton::SetFont(const BFont* font, uint32 mask)
{
	BButton::SetFont(font,mask);
	AdjustSizeForFont();
}


void FSButton::AdjustSizeForFont()
{
	float width, height;
	GetPreferredSize(&width,&height);
	if(m_width_mode != B_WIDTH_AS_USUAL)
	{
		BFont font;
		GetFont(&font);
		struct font_height font_height_struct;
		font.GetHeight(&font_height_struct);
		width = font.StringWidth(Label())+ceil(font_height_struct.ascent+font_height_struct.descent)*2;
	}
	ResizeTo(width,height);
}


float FSButton::VisualLeft()
{
	return Frame().left+1;
}


float FSButton::VisualRight()
{
	return Frame().right-1;
}


float FSButton::VisualTop()
{
	return Frame().top+1;
}


float FSButton::VisualBottom()
{
	return Frame().bottom-1;
}


void FSButton::SetVisualWidth(float width)
{
	ResizeTo(width+2,Frame().Height());
}


void FSButton::SetVisualHeight(float height)
{
	ResizeTo(Frame().Width(),height+2);
}


void FSButton::SetVisualSize(float width, float height)
{
	ResizeTo(width+2,height+2);
}


void FSButton::MoveToVisualPosition(BPoint visual_position)
{
	MoveTo(visual_position.x-1,visual_position.y-1);
}
