//Name:		FSLeftLabelView.cpp
//Author:	Brian Tietz
//Copyright 1999
//Conventions:
//	Global constants (declared with const) and #defines - begin with "c_" followed by lowercase
//		words separated by underscores.
//		(E.G., #define c_my_constant 5).
//		(E.G., const int c_my_constant = 5;).
//	Global variables - begin with "g_" followed by lowercase words separated by underscores.
//		(E.G., int g_my_global;).
//	New data types (classes, structs, typedefs, etc.) - begin with an uppercase letter followed by
//		lowercase words separated by uppercase letters.  Enumerated constants contain a prefix
//		associating them with a particular enumerated set.
//		(E.G., typedef int MyTypedef;).
//		(E.G., enum MyEnumConst {c_mec_one, c_mec_two};)
//	Private member variables - begin with "m_" followed by lowercase words separated by underscores.
//		(E.G., int m_my_member;).
//	Public or friend-accessible member variables - all lowercase words separated by underscores.
//		(E.G., int public_member;).
//	Argument and local variables - begin with a lowercase letter followed by
//		lowercase words separated by underscores.  If the name is already taken by a public member
//		variable, prefix with a_ or l_
//		(E.G., int my_local; int a_my_arg, int l_my_local).
//	Functions (member or global) - begin with an uppercase letter followed by lowercase words
//		separated by uppercase letters.
//		(E.G., void MyFunction(void);).


//******************************************************************************************************
//**** Project header files
//******************************************************************************************************
#include "FSLeftLabelView.h"


//******************************************************************************************************
//**** FSLeftLabelView
//******************************************************************************************************
void FSLeftLabelView::Align(FSLeftLabelView** labelled_views, int32 num_views, bool align_left,
	bool align_divider, bool align_right, bool space_vertically, float v_spacing)
{
	int32 view_index;

	//Align them horizontally, and space them vertically if requested
	if(space_vertically || align_left)
		for(view_index = 1; view_index < num_views; view_index++)
		{
			BPoint visual_position = labelled_views[view_index]->VisualPosition();
			if(space_vertically)
				visual_position.y = labelled_views[view_index-1]->VisualBottom()+v_spacing+1;
			if(align_left)
				visual_position.x = labelled_views[0]->VisualLeft();
			labelled_views[view_index]->MoveToVisualPosition(visual_position);
		}

	//Align the divider position if requested
	if(align_divider)
	{
		float max_divider_pos = 0;
		float divider;
		for(view_index = 0; view_index < num_views; view_index++)
		{
			divider = labelled_views[view_index]->VisualDivider();
			if(max_divider_pos < divider)
				max_divider_pos = divider;
		}
		for(view_index = 0; view_index < num_views; view_index++)
		{
			divider = labelled_views[view_index]->VisualDivider();
			if(divider < max_divider_pos)
			{
				labelled_views[view_index]->SetVisualWidth(labelled_views[view_index]->VisualWidth() +
					(max_divider_pos-divider));
				labelled_views[view_index]->SetVisualDivider(max_divider_pos);
			}
		}
	}

	//Align the right edge if requested
	if(align_right)
	{
		float max_right = labelled_views[0]->VisualRight();
		float right;
		for(view_index = 1; view_index < num_views; view_index++)
		{
			right = labelled_views[view_index]->VisualRight();
			if(max_right < right)
				max_right = right;
		}
		for(view_index = 0; view_index < num_views; view_index++)
		{
			right = labelled_views[view_index]->VisualRight();
			if(right < max_right)
				labelled_views[view_index]->SetVisualWidth(labelled_views[view_index]->VisualWidth() +
					max_right-right);
		}
	}
}

