//Name:		FSMenuField.cpp
//Author:	Brian Tietz
//Copyright 1999
//Conventions:
//	Global constants (declared with const) and #defines - begin with "c_" followed by lowercase
//		words separated by underscores.
//		(E.G., #define c_my_constant 5).
//		(E.G., const int c_my_constant = 5;).
//	Global variables - begin with "g_" followed by lowercase words separated by underscores.
//		(E.G., int g_my_global;).
//	New data types (classes, structs, typedefs, etc.) - begin with an uppercase letter followed by
//		lowercase words separated by uppercase letters.  Enumerated constants contain a prefix
//		associating them with a particular enumerated set.
//		(E.G., typedef int MyTypedef;).
//		(E.G., enum MyEnumConst {c_mec_one, c_mec_two};)
//	Private member variables - begin with "m_" followed by lowercase words separated by underscores.
//		(E.G., int m_my_member;).
//	Public or friend-accessible member variables - all lowercase words separated by underscores.
//		(E.G., int public_member;).
//	Argument and local variables - begin with a lowercase letter followed by
//		lowercase words separated by underscores.  If the name is already taken by a public member
//		variable, prefix with a_ or l_
//		(E.G., int my_local; int a_my_arg, int l_my_local).
//	Functions (member or global) - begin with an uppercase letter followed by lowercase words
//		separated by uppercase letters.
//		(E.G., void MyFunction(void);).


//******************************************************************************************************
//**** Project header files
//******************************************************************************************************
#include <MenuItem.h>
#include <MenuBar.h>


//******************************************************************************************************
//**** Project header files
//******************************************************************************************************
#include "FSMenuField.h"


//******************************************************************************************************
//**** FSMenuField
//******************************************************************************************************
FSMenuField::FSMenuField(const char* name, const char* label, BMenu* menu, bool fixed_size,
	uint32 resize, uint32 flags)
: BMenuField(BRect(0,0,160,20),name,label,menu,fixed_size,resize,flags)
{
	BFont font;
	GetFont(&font);
	struct font_height font_height_struct;
	font.GetHeight(&font_height_struct);

	float width = WidestStringWidth(&font,menu);
	width = width+21;
	float divider = 1;
	if(label)
	{
		divider = 3+ceil(font.StringWidth(label))+5;
		width += divider-1;
	}

	ResizeTo(width,ceil(font_height_struct.ascent)+ceil(font_height_struct.descent)+9);

	SetDivider(divider);
}


float FSMenuField::WidestStringWidth(const BFont* font, BMenu* menu)
{
	float width = 0;
	int32 num_menu_items = menu->CountItems();
	for(int i=0; i<num_menu_items; i++)
	{
		const char* label = menu->ItemAt(i)->Label();
		float item_width = (label ? (ceil(font->StringWidth(label))) : 0);
		if(item_width > width)
			width = item_width;
		if(menu->SubmenuAt(i))
		{
			item_width = WidestStringWidth(font,menu->SubmenuAt(i));
			if(item_width > width)
				width = item_width;
		}
	}
	return width;
}


float FSMenuField::VisualLeft()
{
	if(Label() == NULL)
	{
		//No label
		if(Divider() < 1)
			return Frame().left+1;
		return Frame().left+Divider()+1;
	}
	else
		return Frame().left+3;
}


float FSMenuField::VisualRight()
{
	return Frame().right-1;
}


float FSMenuField::VisualTop()
{
	return Frame().top+2;
}


float FSMenuField::VisualBottom()
{
	return Frame().bottom-2;
}


void FSMenuField::SetVisualWidth(float width)
{
	ResizeTo(width+Frame().Width()-VisualWidth(),Frame().Height());
	//BEBUG: Lame that I need to do this...consequence of resizing
	MenuBar()->SetMaxContentWidth(WidestStringWidth()+6);
}


void FSMenuField::SetVisualHeight(float height)
{
	ResizeTo(Frame().Width(),Frame().Height()+4);
}


void FSMenuField::SetVisualSize(float width, float height)
{
	ResizeTo(width+Frame().Width()-VisualWidth(),Frame().Height()+4);
	//BEBUG: Lame that I need to do this...consequence of resizing
	MenuBar()->SetMaxContentWidth(WidestStringWidth()+6);
}


void FSMenuField::MoveToVisualPosition(BPoint visual_position)
{
	MoveTo(visual_position.x-(VisualLeft()-Frame().left),visual_position.y-2);
}


float FSMenuField::VisualDivider()
{
	return Divider()+1-(VisualLeft()-Frame().left);
}


void FSMenuField::SetVisualDivider(float divider)
{
	SetDivider(divider-1+(VisualLeft()-Frame().left));
	//BEBUG: Lame that I need to do this...consequence of resizing
	MenuBar()->SetMaxContentWidth(WidestStringWidth()+6);
}


float FSMenuField::WidestStringWidth()
{
	BFont font;
	Menu()->GetFont(&font);
	return WidestStringWidth(&font,Menu());
}


