//Name:		FSMultiLineTextControl.cpp
//Author:	Brian Tietz
//Copyright 1999
//Conventions:
//	Global constants (declared with const) and #defines - begin with "c_" followed by lowercase
//		words separated by underscores.
//		(E.G., #define c_my_constant 5).
//		(E.G., const int c_my_constant = 5;).
//	Global variables - begin with "g_" followed by lowercase words separated by underscores.
//		(E.G., int g_my_global;).
//	New data types (classes, structs, typedefs, etc.) - begin with an uppercase letter followed by
//		lowercase words separated by uppercase letters.  Enumerated constants contain a prefix
//		associating them with a particular enumerated set.
//		(E.G., typedef int MyTypedef;).
//		(E.G., enum MyEnumConst {c_mec_one, c_mec_two};)
//	Private member variables - begin with "m_" followed by lowercase words separated by underscores.
//		(E.G., int m_my_member;).
//	Public or friend-accessible member variables - all lowercase words separated by underscores.
//		(E.G., int public_member;).
//	Argument and local variables - begin with a lowercase letter followed by
//		lowercase words separated by underscores.  If the name is already taken by a public member
//		variable, prefix with a_ or l_
//		(E.G., int my_local; int a_my_arg, int l_my_local).
//	Functions (member or global) - begin with an uppercase letter followed by lowercase words
//		separated by uppercase letters.
//		(E.G., void MyFunction(void);).


//******************************************************************************************************
//**** Project header files
//******************************************************************************************************
#include "FSMultiLineTextControl.h"


//******************************************************************************************************
//**** FSMultiLineTextControl
//******************************************************************************************************
#include <stdio.h>
FSMultiLineTextControl::FSMultiLineTextControl(const char *name, const char *label, const char *text,
	BMessage *message, uint32 resizing_mode, uint32 flags)
: MultiLineTextControl(BRect(0,0,100,40),name,label,false,text,message,resizing_mode,flags)
{
	BFont font;
	GetFont(&font);
	struct font_height curr_font_height;
	font.GetHeight(&curr_font_height);
	m_label_font_ascent = ceil(curr_font_height.ascent);
	m_font_height = m_label_font_ascent + ceil(curr_font_height.descent);
	m_font_leading = ceil(curr_font_height.leading);

	const char* string[1] = {label};
	struct escapement_delta deltas[1] = {{0,0}};
	BRect bounding_box[1];
	be_plain_font->GetBoundingBoxesForStrings(string,1,B_SCREEN_METRIC,deltas,bounding_box);
	m_title_true_ascent = ceil(0-bounding_box[0].top);

	float min_width = 6 + font.StringWidth(label) + 6;
	float min_height = RequiredHeight(1);
	ResizeToWithChildren(min_width,min_height);
}


float FSMultiLineTextControl::RequiredHeight(int num_lines)
{
	return m_font_height + 3 + 2 + m_font_height*num_lines + m_font_leading*(num_lines-1) + 3;
}


float FSMultiLineTextControl::VisualLeft()
{
	return Frame().left;
}


float FSMultiLineTextControl::VisualRight()
{
	return Frame().right;
}


float FSMultiLineTextControl::VisualTop()
{
	return Frame().top + m_label_font_ascent - m_title_true_ascent;
}


float FSMultiLineTextControl::VisualBottom()
{
	return Frame().bottom;
}


void FSMultiLineTextControl::SetVisualWidth(float width)
{
	ResizeToWithChildren(width,Frame().Height());
}


void FSMultiLineTextControl::SetVisualHeight(float height)
{
	ResizeToWithChildren(Frame().Width(),height+Frame().Height()-VisualHeight());
}


void FSMultiLineTextControl::SetVisualSize(float width, float height)
{
	ResizeToWithChildren(width,height+Frame().Height()-VisualHeight());
}


void FSMultiLineTextControl::MoveToVisualPosition(BPoint visual_position)
{
	MoveTo(visual_position.x,visual_position.y-(m_label_font_ascent-m_title_true_ascent));
}
