//Name:		FSMultiLineTextControl.h
//Author:	Brian Tietz
//Copyright 1999
//Conventions:
//	Global constants (declared with const) and #defines - begin with "c_" followed by lowercase
//		words separated by underscores.
//		(E.G., #define c_my_constant 5).
//		(E.G., const int c_my_constant = 5;).
//	Global variables - begin with "g_" followed by lowercase words separated by underscores.
//		(E.G., int g_my_global;).
//	New data types (classes, structs, typedefs, etc.) - begin with an uppercase letter followed by
//		lowercase words separated by uppercase letters.  Enumerated constants contain a prefix
//		associating them with a particular enumerated set.
//		(E.G., typedef int MyTypedef;).
//		(E.G., enum MyEnumConst {c_mec_one, c_mec_two};)
//	Private member variables - begin with "m_" followed by lowercase words separated by underscores.
//		(E.G., int m_my_member;).
//	Public or friend-accessible member variables - all lowercase words separated by underscores.
//		(E.G., int public_member;).
//	Argument and local variables - begin with a lowercase letter followed by
//		lowercase words separated by underscores.  If the name is already taken by a public member
//		variable, prefix with a_ or l_
//		(E.G., int my_local; int a_my_arg, int l_my_local).
//	Functions (member or global) - begin with an uppercase letter followed by lowercase words
//		separated by uppercase letters.
//		(E.G., void MyFunction(void);).


#ifndef _FONT_SENSITIVE_MULTILINE_TEXT_CONTROL_H_
#define _FONT_SENSITIVE_MULTILINE_TEXT_CONTROL_H_


//******************************************************************************************************
//**** Project header files
//******************************************************************************************************
#include "FSView.h"
#include "MultiLineTextControl.h"


//******************************************************************************************************
//**** FSMultiLineTextControl
//******************************************************************************************************
class FSMultiLineTextControl : public MultiLineTextControl, public FSView
{
	public:
		FSMultiLineTextControl(const char* name, const char* label, const char *text, BMessage *message,
			uint32 resizing_mode = B_FOLLOW_LEFT|B_FOLLOW_TOP, uint32 flags = B_WILL_DRAW|B_NAVIGABLE);
			//Created at the minimum height necessary to show one line of text, and the minimum width
			//necessary to accommodate the label.

		float RequiredHeight(int num_lines);

		//FSView implementation
		virtual float VisualLeft();
		virtual float VisualRight();
		virtual float VisualTop();
		virtual float VisualBottom();
		virtual void SetVisualWidth(float width);
		virtual void SetVisualHeight(float height);
		virtual void SetVisualSize(float width, float height);
		virtual void MoveToVisualPosition(BPoint visual_position);

	private:
		float m_label_font_ascent;
		float m_font_height;
		float m_font_leading;
		float m_title_true_ascent;
};


#endif //_FONT_SENSITIVE_MULTILINE_TEXT_CONTROL_H_
