//Name:		FSTextControl.cpp
//Author:	Brian Tietz
//Copyright 1999
//Conventions:
//	Global constants (declared with const) and #defines - begin with "c_" followed by lowercase
//		words separated by underscores.
//		(E.G., #define c_my_constant 5).
//		(E.G., const int c_my_constant = 5;).
//	Global variables - begin with "g_" followed by lowercase words separated by underscores.
//		(E.G., int g_my_global;).
//	New data types (classes, structs, typedefs, etc.) - begin with an uppercase letter followed by
//		lowercase words separated by uppercase letters.  Enumerated constants contain a prefix
//		associating them with a particular enumerated set.
//		(E.G., typedef int MyTypedef;).
//		(E.G., enum MyEnumConst {c_mec_one, c_mec_two};)
//	Private member variables - begin with "m_" followed by lowercase words separated by underscores.
//		(E.G., int m_my_member;).
//	Public or friend-accessible member variables - all lowercase words separated by underscores.
//		(E.G., int public_member;).
//	Argument and local variables - begin with a lowercase letter followed by
//		lowercase words separated by underscores.  If the name is already taken by a public member
//		variable, prefix with a_ or l_
//		(E.G., int my_local; int a_my_arg, int l_my_local).
//	Functions (member or global) - begin with an uppercase letter followed by lowercase words
//		separated by uppercase letters.
//		(E.G., void MyFunction(void);).


//******************************************************************************************************
//**** Project header files
//******************************************************************************************************
#include "FSTextControl.h"


//******************************************************************************************************
//**** FSTextControl
//******************************************************************************************************
FSTextControl::FSTextControl(const char* name, const char* label, const char* text, BMessage* message,
	float entry_area_width, uint32 resizing_mode, uint32 flags)
: BTextControl(BRect(0,0,100,16),name,label,text,message,resizing_mode,flags)
{
	m_entry_area_width = entry_area_width;
	AdjustSizeForFont();
}


void FSTextControl::SetFont(const BFont* font, uint32 properties)
{
	BTextControl::SetFont(font,properties);
	AdjustSizeForFont();
}


void FSTextControl::AdjustSizeForFont()
{
	BFont font;
	GetFont(&font);

	const char* label = Label();
	if(label != NULL)
		SetVisualDivider(ceil(font.StringWidth(label))+6);

	float entry_area_width = m_entry_area_width;
	if(entry_area_width < 0)
	{
		const char* text = Text();
		if(text != NULL)
			entry_area_width = ceil(font.StringWidth(text))+15;
		else
			entry_area_width = 15;
	}

	float dummy,height;
	GetPreferredSize(&dummy,&height);
	ResizeTo(Bounds().Width(),height);
	SetVisualWidth(Divider()+entry_area_width);
}


float FSTextControl::VisualDivider()
{
	return Divider() + 3 - (VisualLeft()-Frame().left);
}


void FSTextControl::SetVisualDivider(float divider)
{
	SetDivider(divider - 3 + (VisualLeft()-Frame().left));
}


void FSTextControl::SetVisualWidth(float width)
{
	width += 3;		//Three blank pixels along left edge of label
	BRect original_bounds = Bounds();
	BRect old_child_bounds = TextView()->Bounds();
	ResizeTo(width,original_bounds.Height());

	//To compensate for a BeOS problem with the available resize functions
	TextView()->ResizeTo(old_child_bounds.Width()+(width-original_bounds.Width()),
		old_child_bounds.Height());
}


void FSTextControl::SetVisualHeight(float height)
{
	height += 1;		//one blank pixel along bottom edge
	BRect original_bounds = Bounds();
	BRect old_child_bounds = TextView()->Bounds();
	ResizeTo(original_bounds.Width(),height);

	//To compensate for a BeOS problem with the available resize functions
	TextView()->ResizeTo(old_child_bounds.Width(),old_child_bounds.Height()+
		(height-original_bounds.Height()));
}


void FSTextControl::SetVisualSize(float width, float height)
{
	width += 3;		//Three blank pixels along left edge of label
	height += 1;		//one blank pixel along bottom edge
	BRect original_bounds = Bounds();
	BRect old_child_bounds = TextView()->Bounds();
	ResizeTo(width,height);

	//To compensate for a BeOS problem with the available resize functions
	TextView()->ResizeTo(old_child_bounds.Width()+(width-original_bounds.Width()),
		old_child_bounds.Height()+(height-original_bounds.Height()));
}


float FSTextControl::VisualLeft()
{
	return Frame().left+3;
}


float FSTextControl::VisualRight()
{
	return Frame().right;
}


float FSTextControl::VisualTop()
{
	return Frame().top;
}


float FSTextControl::VisualBottom()
{
	return Frame().bottom-1;
}


void FSTextControl::MoveToVisualPosition(BPoint visual_position)
{
	MoveTo(visual_position.x-3,visual_position.y);
}
