//Name:		FSView.cpp
//Author:	Brian Tietz
//Copyright 1999
//Conventions:
//	Global constants (declared with const) and #defines - begin with "c_" followed by lowercase
//		words separated by underscores.
//		(E.G., #define c_my_constant 5).
//		(E.G., const int c_my_constant = 5;).
//	Global variables - begin with "g_" followed by lowercase words separated by underscores.
//		(E.G., int g_my_global;).
//	New data types (classes, structs, typedefs, etc.) - begin with an uppercase letter followed by
//		lowercase words separated by uppercase letters.  Enumerated constants contain a prefix
//		associating them with a particular enumerated set.
//		(E.G., typedef int MyTypedef;).
//		(E.G., enum MyEnumConst {c_mec_one, c_mec_two};)
//	Private member variables - begin with "m_" followed by lowercase words separated by underscores.
//		(E.G., int m_my_member;).
//	Public or friend-accessible member variables - all lowercase words separated by underscores.
//		(E.G., int public_member;).
//	Argument and local variables - begin with a lowercase letter followed by
//		lowercase words separated by underscores.  If the name is already taken by a public member
//		variable, prefix with a_ or l_
//		(E.G., int my_local; int a_my_arg, int l_my_local).
//	Functions (member or global) - begin with an uppercase letter followed by lowercase words
//		separated by uppercase letters.
//		(E.G., void MyFunction(void);).


//******************************************************************************************************
//**** Project header files
//******************************************************************************************************
#include "FSView.h"


//******************************************************************************************************
//**** FSView
//******************************************************************************************************
float FSView::VisualWidth()
{
	return VisualRight()-VisualLeft();
}


float FSView::VisualHeight()
{
	return VisualBottom()-VisualTop();
}


BPoint FSView::VisualPosition()
{
	return BPoint(VisualLeft(),VisualTop());
}


BRect FSView::VisualFrame()
{
	return BRect(VisualLeft(),VisualTop(),VisualRight(),VisualBottom());
}


void FSView::Align(FSView** views, int32 num_views, bool align_left, bool align_right,
	bool space_vertically, float v_spacing)
{
	int32 view_index;

	//Align them horizontally, and space them vertically if requested
	if(space_vertically || align_left)
		for(view_index = 1; view_index < num_views; view_index++)
		{
			BPoint visual_position = views[view_index]->VisualPosition();
			if(space_vertically)
				visual_position.y = views[view_index-1]->VisualBottom()+v_spacing+1;
			if(align_left)
				visual_position.x = views[0]->VisualLeft();
			views[view_index]->MoveToVisualPosition(visual_position);
		}

	//Align the right edge if requested
	if(align_right)
	{
		float max_right = views[0]->VisualRight();
		float right;
		for(view_index = 1; view_index < num_views; view_index++)
		{
			right = views[view_index]->VisualRight();
			if(max_right < right)
				max_right = right;
		}
		for(view_index = 0; view_index < num_views; view_index++)
		{
			right = views[view_index]->VisualRight();
			if(right < max_right)
				views[view_index]->SetVisualWidth(views[view_index]->VisualWidth() +
					max_right-right);
		}
	}
}


void FSView::Align(FSView** views, int32 num_views_x, int32 num_views_y, float v_spacing,
	float h_spacing, bool even_x, bool even_y, bool resize_h, bool resize_v)
{
	int32 x;
	int32 y;
	float max_column_width = 0;
	float max_row_height = 0;
	if(even_x)
		for(x=0; x<num_views_x*num_views_y; x++)
			if(max_column_width < views[x]->VisualWidth())
				max_column_width = views[x]->VisualWidth();
	if(even_y)
		for(x=0; x<num_views_x*num_views_y; x++)
			if(max_row_height < views[x]->VisualHeight())
				max_row_height = views[x]->VisualHeight();

	float next_column_left = views[0]->VisualLeft();
	float all_columns_top = views[0]->VisualTop();
	for(x=0; x<num_views_x; x++)
	{
		float next_row_top = all_columns_top;
		if(!even_x)
		{
			max_column_width = 0;
			for(y=0; y<num_views_y; y++)		
				if(max_column_width < views[y*num_views_x+x]->VisualWidth())
					max_column_width = views[y*num_views_x+x]->VisualWidth();
		}
		for(y=0; y<num_views_y; y++)
		{
			if(!even_y)
			{
				max_row_height = 0;
				for(int32 x2=0; x2<num_views_x; x2++)
					if(max_row_height < views[y*num_views_x+x2]->VisualHeight())
						max_row_height = views[y*num_views_x+x2]->VisualHeight();
			}
			views[y*num_views_x+x]->MoveToVisualPosition(BPoint(next_column_left,next_row_top+
				ceil((max_row_height-views[y*num_views_x+x]->VisualHeight())/2)));
			if(resize_h)
				views[y*num_views_x+x]->SetVisualWidth(max_column_width);
			if(resize_v)
				views[y*num_views_x+x]->SetVisualWidth(max_row_height);
			next_row_top = next_row_top + max_row_height + 1 + v_spacing;
		}
		next_column_left = next_column_left + max_column_width + 1 + h_spacing;
	}
}
