//Name:		FSView.h
//Author:	Brian Tietz
//Copyright 1999
//Conventions:
//	Global constants (declared with const) and #defines - begin with "c_" followed by lowercase
//		words separated by underscores.
//		(E.G., #define c_my_constant 5).
//		(E.G., const int c_my_constant = 5;).
//	Global variables - begin with "g_" followed by lowercase words separated by underscores.
//		(E.G., int g_my_global;).
//	New data types (classes, structs, typedefs, etc.) - begin with an uppercase letter followed by
//		lowercase words separated by uppercase letters.  Enumerated constants contain a prefix
//		associating them with a particular enumerated set.
//		(E.G., typedef int MyTypedef;).
//		(E.G., enum MyEnumConst {c_mec_one, c_mec_two};)
//	Private member variables - begin with "m_" followed by lowercase words separated by underscores.
//		(E.G., int m_my_member;).
//	Public or friend-accessible member variables - all lowercase words separated by underscores.
//		(E.G., int public_member;).
//	Argument and local variables - begin with a lowercase letter followed by
//		lowercase words separated by underscores.  If the name is already taken by a public member
//		variable, prefix with a_ or l_
//		(E.G., int my_local; int a_my_arg, int l_my_local).
//	Functions (member or global) - begin with an uppercase letter followed by lowercase words
//		separated by uppercase letters.
//		(E.G., void MyFunction(void);).


#ifndef _FONT_SENSITIVE_VIEW_H_
#define _FONT_SENSITIVE_VIEW_H_


//******************************************************************************************************
//**** System header files
//******************************************************************************************************
#include <Point.h>
#include <Rect.h>


//******************************************************************************************************
//**** FSView
//******************************************************************************************************
class FSView
{
	public:
		//For derived classes to implement
		virtual float VisualWidth();
		virtual float VisualHeight();
		virtual float VisualLeft() = 0;
		virtual float VisualRight() = 0;
		virtual float VisualTop() = 0;
		virtual float VisualBottom() = 0;
		virtual BPoint VisualPosition();
		virtual BRect VisualFrame();
		virtual void SetVisualWidth(float width) = 0;
		virtual void SetVisualHeight(float height) = 0;
		virtual void SetVisualSize(float width, float height) = 0;
		virtual void MoveToVisualPosition(BPoint visual_position) = 0;

		static void Align(FSView** views, int32 num_views, bool align_left = true,
			bool align_right = true, bool space_vertically = true, float v_spacing = 5);
			//The position of labelled_views[0] is used as the starting point
		static void Align(FSView** views, int32 num_views_x, int32 num_views_y, float v_spacing = 5,
			float h_spacing = 7, bool even_x = false, bool even_y = true, bool resize_h = false,
			bool resize_v = false);
			//Align a grid of views.  views should be ordered x0y0,x1y0, ... xny0, x0y1, ...
			//If even_x is true, each column is evenly spaced, otherwise columns are packed to minimum
			//width to fit all elements in the column.  Same for even_y.  The position of views[0] is
			//used as the starting point.  if resize_h or resize_v is specified, the views are resized
			//along the appropriate axis to be uniformly sized.
};


#endif //_FONT_SENSITIVE_VIEW_H_
