//Name:		NumericTextFieldUtilities.cpp
//Author:	Brian Tietz
//Copyright 2000
//Conventions:
//	Global constants (declared with const) and #defines - begin with "c_" followed by lowercase
//		words separated by underscores.
//		(E.G., #define c_my_constant 5).
//		(E.G., const int c_my_constant = 5;).
//	Global variables - begin with "g_" followed by lowercase words separated by underscores.
//		(E.G., int g_my_global;).
//	New data types (classes, structs, typedefs, etc.) - begin with an uppercase letter followed by
//		lowercase words separated by uppercase letters.  Enumerated constants contain a prefix
//		associating them with a particular enumerated set.
//		(E.G., typedef int MyTypedef;).
//		(E.G., enum MyEnumConst {c_mec_one, c_mec_two};)
//	Private member variables - begin with "m_" followed by lowercase words separated by underscores.
//		(E.G., int m_my_member;).
//	Public or friend-accessible member variables - all lowercase words separated by underscores.
//		(E.G., int public_member;).
//	Argument and local variables - begin with a lowercase letter followed by
//		lowercase words separated by underscores.  If the name is already taken by a public member
//		variable, prefix with a_ or l_
//		(E.G., int my_local; int a_my_arg, int l_my_local).
//	Functions (member or global) - begin with an uppercase letter followed by lowercase words
//		separated by uppercase letters.
//		(E.G., void MyFunction(void);).


//******************************************************************************************************
//**** Project header files and forward name declarations
//******************************************************************************************************
#include <stdio.h>
#include <stdlib.h>


//******************************************************************************************************
//**** Project header files and forward name declarations
//******************************************************************************************************
#include "NumericTextFieldUtilities.h"


//******************************************************************************************************
//**** NumericTextFieldUtilities
//******************************************************************************************************
int32 CheckIntegralValue(BTextControl* field, int32 min, int32 max)
{
	const char* text = field->Text();
	int length = strlen(text);
	int32 value = 0;
	bool legal = true;
	for(int i=0; i<length; i++)
		if(!((text[i]>='0' && text[i]<='9') || (text[0]=='-' && i==0)))
			legal = false;
	if(legal)
		value = atoi(text);
	if(value < min || value > max || !legal)
	{
		if(value < min)
			value = min;
		else if(value > max)
			value = max;
		char num_buffer[12];
		sprintf(num_buffer,"%d",value);
		field->SetText(num_buffer);
	}
	return value;
}


int32 CheckIntegralFloatValue(BTextControl* text_control, int32 min, int32 max,
	int8 digits_after_decimal, BSlider* slider_partner)
{
	const char* text = text_control->Text();
	int32 value = 0;
	int32 decimal_multiplier = 1;
	for(int j=0; j<digits_after_decimal; j++)
		decimal_multiplier *= 10;
	float saved_decimal_multiplier = (float)decimal_multiplier;
	bool legal = true;
	bool negate = (text[0] == '-');
	if(text[0] == '-')
		text++;
	int32 length = strlen(text);
	bool found_decimal_already = false;
	for(int i=0; i<length; i++)
	{
		if(!((text[i]>='0' && text[i]<='9') || text[i]=='.'))
		{
			legal = false;
			break;
		}
		if(text[i]=='.')
		{
			if(found_decimal_already)
			{
				legal = false;
				break;
			}
			found_decimal_already = true;
			value = value * decimal_multiplier;
		}
		else
		{
			if(!found_decimal_already)
				value = value * 10 + text[i] - '0';
			else
			{
				decimal_multiplier /= 10;
				value = value + (text[i]-'0')*decimal_multiplier;
			}
		}
	}
	if(!found_decimal_already)
		value = value * decimal_multiplier;
	if(negate)
		value = 0-value;
	if(!legal)
		value = 0;
	if(value < min || value > max || !legal)
	{
		if(value < min)
			value = min;
		else if(value > max)
			value = max;
		char num_buffer[32];
		char pattern[6] = "%.00f";
		pattern[3] = digits_after_decimal+'0';
		sprintf(num_buffer,pattern,((float)value)/saved_decimal_multiplier);
		text_control->SetText(num_buffer);
	}
	if(slider_partner)
		slider_partner->SetValue(value);
	return value;
}


int32 SetIntegralFloatValueFromSlider(BTextControl* text_control, int8 digits_after_decimal,
	BSlider* slider_partner)
{
	int32 value = slider_partner->Value();
	int32 decimal_multiplier = 1;
	for(int j=0; j<digits_after_decimal; j++)
		decimal_multiplier *= 10;
	char num_buffer[32];
	char pattern[6] = "%.00f";
	pattern[3] = digits_after_decimal+'0';
	sprintf(num_buffer,pattern,((float)value)/((float)decimal_multiplier));
	text_control->SetText(num_buffer);
	return value;
}
