//Name:		NumericTextFieldUtilities.h
//Author:	Brian Tietz
//Copyright 2000
//Conventions:
//	Global constants (declared with const) and #defines - begin with "c_" followed by lowercase
//		words separated by underscores.
//		(E.G., #define c_my_constant 5).
//		(E.G., const int c_my_constant = 5;).
//	Global variables - begin with "g_" followed by lowercase words separated by underscores.
//		(E.G., int g_my_global;).
//	New data types (classes, structs, typedefs, etc.) - begin with an uppercase letter followed by
//		lowercase words separated by uppercase letters.  Enumerated constants contain a prefix
//		associating them with a particular enumerated set.
//		(E.G., typedef int MyTypedef;).
//		(E.G., enum MyEnumConst {c_mec_one, c_mec_two};)
//	Private member variables - begin with "m_" followed by lowercase words separated by underscores.
//		(E.G., int m_my_member;).
//	Public or friend-accessible member variables - all lowercase words separated by underscores.
//		(E.G., int public_member;).
//	Argument and local variables - begin with a lowercase letter followed by
//		lowercase words separated by underscores.  If the name is already taken by a public member
//		variable, prefix with a_ or l_
//		(E.G., int my_local; int a_my_arg, int l_my_local).
//	Functions (member or global) - begin with an uppercase letter followed by lowercase words
//		separated by uppercase letters.
//		(E.G., void MyFunction(void);).


#ifndef _NUMERIC_TEXT_FIELD_UTILITES_H_
#define _NUMERIC_TEXT_FIELD_UTILITES_H_


//******************************************************************************************************
//**** System header files
//******************************************************************************************************
#include <TextControl.h>
#include <Slider.h>


//******************************************************************************************************
//**** NumericTextFieldUtilities
//******************************************************************************************************
int32 CheckIntegralValue(BTextControl* field, int32 min, int32 max);
	//Utility function: returns the numeric content of the text control, checking it for being a valid
	//number, checking against min, max, and changing the text in the BTextControl if necessary to
	//ensure legality and that the number is in range.
int32 CheckIntegralFloatValue(BTextControl* text_control, int32 min, int32 max,
	int8 digits_after_decimal, BSlider* slider_partner = NULL);
	//Utility function: returns the numeric content of the text control, checking it for being a valid
	//number, checking against min, max, and changing the text in the BTextControl if necessary to
	//ensure legality and that the number is in range.  Once that is done, if a slider_partner is
	//specified, the slider's value is set to match the floating point value.  Returns the integral
	//value representing the float.
int32 SetIntegralFloatValueFromSlider(BTextControl* text_control, int8 digits_after_decimal,
	BSlider* slider_partner);
	//Utility function: sets the value of text_control to match slider_partner, converting to floating
	//point ascii from the fixed point slider value.  For example, if the slider value is 100 and
	//digits_after_decimal is 2, then the text_control is set to 1.00.  Returns the integral value
	//representing the float.


#endif //_NUMERIC_TEXT_FIELD_UTILITES_H_
